@@ -130,7 +130,7 @@ class Client:
         else:
             raise exceptions.CakeworkError("Internal server exception") 
     
-    def run(self, project, task, params, compute ={"cpu":1, "memory": 256}):
+    def run(self, task, params, compute ={"cpu":1, "memory": 256}):
         sanitized_task = task.lower()
         sanitized_task = task.replace('_', '-')
 
@@ -154,7 +154,7 @@ class Client:
     
         # print(request) # TODO delete
 
-        response = requests.post(f"{self.frontend_url}/client/projects/{project}/tasks/{sanitized_task}/runs", json=request, headers=self.headers)
+        response = requests.post(f"{self.frontend_url}/client/projects/{self.project}/tasks/{sanitized_task}/runs", json=request, headers=self.headers)
         response_json = response.json()
         run_id = response_json["runId"] # this may be null?
         return run_id
\ No newline at end of file
